//! # WebSocket routes
//!
//! @author Pierre Hubert

use crate::data::error::Res;
use crate::data::user_ws_request_handler::WsRequestHandler;

pub type WsRequestProcess = Box<dyn Fn(&mut WsRequestHandler) -> Res>;

/// WebSocket route
pub struct UserWsRoute {
    pub route: String,
    pub handler: WsRequestProcess,
}

impl UserWsRoute {
    pub fn new<H>(route: &str, handler: H) -> UserWsRoute
        where H: 'static + Fn(&mut WsRequestHandler) -> Res {
        UserWsRoute {
            route: route.to_string(),
            handler: Box::new(handler),
        }
    }
}

/// Get the list of available WebSocket routes
pub fn get_user_ws_routes() -> Vec<UserWsRoute> {
    vec![]
}

/// Search for a route
pub fn find_user_ws_route(uri: &str) -> Option<UserWsRoute> {
    get_user_ws_routes().into_iter().find(|r| r.route == uri)
}